Examples
========

.. contents::
   :local:

Getting Started and IO
----------------------

.. nbgallery::
   :glob:

   examples/getting_started_io/*

Signal Quality
-----------------------

.. nbgallery::
   :glob:

   examples/signal_quality/*

Modeling
-----------------------

.. nbgallery::
   :glob:

   examples/modeling/*

Head Models and Image Reconstruction
-------------------------------------

.. nbgallery::
   :glob:

   examples/head_models/*

Machine Learning and Data Driven Methods
----------------------------------------

.. nbgallery::
   :glob:

   examples/machine_learning/*

Physiology
-----------------------

.. nbgallery::
   :glob:

   examples/physio/*

Data Augmentation
-----------------------

.. nbgallery::
   :caption: Coming soon
   :glob:

   examples/data_augmentation/*

Plots & Visualization
-----------------------

.. nbgallery::
   :glob:

   examples/plots_visualization/*
